

<a id="confluent-endpoint-endpoint-list"></a>

# confluent endpoint endpoint list

## Description

List endpoints.

```none
confluent endpoint endpoint list [flags]
```

## Flags

```none
    --service string       REQUIRED: Filter the results by exact match for service.
    --cloud string         Specify the cloud provider as "aws", "azure", or "gcp".
    --region string        Filter the results by exact match for region.
    --is-private           Filter the results by whether the endpoint is private (true) or public (false). If not specified, returns both private and public endpoints.
    --environment string   Environment ID.
    --resource string      Filter the results by exact match for resource.
    --context string       CLI context name.
-o, --output string        Specify the output format as "human", "json", or "yaml". (default "human")
```

## Global Flags

```none
-h, --help            Show help for this command.
    --unsafe-trace    Equivalent to -vvvv, but also log HTTP requests and responses which might contain plaintext secrets.
-v, --verbose count   Increase verbosity (-v for warn, -vv for info, -vvv for debug, and -vvvv for trace).
```

## Examples

List Schema Registry endpoints:

```none
confluent endpoint endpoint list --service schema_registry
```

List Flink endpoints:

```none
confluent endpoint endpoint list --service flink --cloud aws --region us-west-2
```

List Kafka endpoints:

```none
confluent endpoint endpoint list --service kafka
```

List Kafka endpoints for a specific cluster:

```none
confluent endpoint endpoint list --service kafka --resource lkc-abc123
```

List only public Schema Registry endpoints:

```none
confluent endpoint endpoint list --service schema_registry --is-private=false
```

## See Also

* [confluent endpoint endpoint](index.md#confluent-endpoint-endpoint) - Manage endpoints.
